@@ -8,18 +8,20 @@ function (aa) {
            "A","C","D","E","F","G",
            "H","I","K","L","M","N","P","Q",
            "R","S","T","V","W","Y",
-           "S","T","K","M","D","C","C","C","C",
-           "H","H","H","H","H","H")
+           "S","T","K","M","D","C","C","C","C","C","C",
+           "H","H","H","H","H","H","H",
+           "M")
   aa3 <- c("---", "---","UNK",
            "ALA", "CYS", "ASP", "GLU", "PHE", "GLY",
            "HIS", "ILE", "LYS", "LEU", "MET", "ASN", "PRO", "GLN",
            "ARG", "SER", "THR", "VAL", "TRP", "TYR",
-           "SEP", "TPO", "MLY", "MSE", "IAS", "ABA","CSO","CSD","CYM",
-           "HIE", "HIP", "HID", "HSD", "HSE", "HSP")
+           "SEP", "TPO", "MLY", "MSE", "IAS", "ABA","CSO","CSD","CYM","CME","CSX",
+           "HIE", "HIP", "HID", "HSD", "HSE", "HSP","DDE",
+           "MHO")
     convert <- function(x) {
       if(is.na(x)) return(NA)
       if (all(x != aa3)) {
-        warning("Unknown 3-letters code for aminoacid")
+        warning(paste("Unknown 3-letters code for aminoacid:",x))
         print(x)
         #return(NA)
         return("X") # mask unk
